@@ -1,3 +1,5 @@
 #!perl -T
 use open ':locale';
+use strict;
+use warnings;
 print "A noite, vovo Kowalsky ve o ima cair no pe do pinguim queixoso e vovo poe acucar no cha de tamaras do jabuti feliz.\n";
